@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from AccessControl import getSecurityManager
 from App.config import getConfiguration
 from copy import deepcopy
@@ -13,29 +12,14 @@ from plone.memoize import ram
 from plone.memoize.volatile import DontCache
 from plone.resource.utils import queryResourceDirectory
 from plone.subrequest import subrequest
-from six.moves.urllib import parse
-from z3c.form.interfaces import IFieldWidget
+from urllib import parse
 from zExceptions import NotFound
 from zExceptions import Unauthorized
-from zope.component import getMultiAdapter
 from zope.component import queryUtility
 from zope.component.hooks import getSite
 from zope.security.interfaces import IPermission
 
 import logging
-import six
-import zope.deferredimport
-
-
-zope.deferredimport.deprecated(
-    "Moved in own behavior due to avoid circular imports. "
-    "Import from plone.app.blocks.layoutbehavior instead",
-    getDefaultAjaxLayout="plone.app.blocks.layoutbehavior:" "getDefaultAjaxLayout",
-    getDefaultSiteLayout="plone.app.blocks.layoutbehavior:" "getDefaultSiteLayout",
-    getLayout="plone.app.blocks.layoutbehavior:getLayout",
-    getLayoutAwareSiteLayout="plone.app.blocks.layoutbehavior:"
-    "getLayoutAwareSiteLayout",
-)
 
 
 headXPath = etree.XPath("/html/head")
@@ -70,7 +54,7 @@ def resolve(url, resolved=None):
             resolved = resolveResource(url)
         except Exception:
             logger.exception(
-                "There was an error while resolving the tile: {0}".format(
+                "There was an error while resolving the tile: {}".format(
                     url,
                 ),
             )
@@ -94,16 +78,11 @@ def resolve(url, resolved=None):
 
     if not resolved.strip():
         return
-
-    if isinstance(resolved, str):
-        resolved = resolved.encode("utf-8")
-
     try:
         html_parser = html.HTMLParser(encoding="utf-8")
         return html.fromstring(resolved, parser=html_parser).getroottree()
-    except etree.XMLSyntaxError as e:
-        logger.error("%s: %s" % (repr(e), url))
-        return
+    except etree.XMLSyntaxError:
+        logger.exception(f"url: {url}")
 
 
 def subresponse_exception_handler(response, exception):
@@ -127,10 +106,10 @@ def resolveResource(url):
         if directory:
             try:
                 res = directory.readFile(path)
-                if isinstance(res, six.binary_type):
+                if isinstance(res, bytes):
                     res = res.decode()
                 return res
-            except (NotFound, IOError):
+            except (NotFound, OSError):
                 pass
 
     if url.startswith("/"):
@@ -145,7 +124,7 @@ def resolveResource(url):
 
     resolved = response.getBody()
 
-    if isinstance(resolved, six.binary_type):
+    if isinstance(resolved, bytes):
         charset = extractCharset(response)
         resolved = resolved.decode(charset)
 
@@ -164,7 +143,7 @@ def resolveResource(url):
 def xpath1(xpath, node, strict=True):
     """Return a single node matched by the given etree.XPath object."""
 
-    if isinstance(xpath, six.string_types):
+    if isinstance(xpath, str):
         xpath = etree.XPath(xpath)
 
     result = xpath(node)
@@ -227,7 +206,7 @@ def remove_element(element):
     parent.remove(element)
 
 
-class PermissionChecker(object):
+class PermissionChecker:
     def __init__(self, permissions, context):
         self.permissions = permissions
         self.context = context
@@ -248,21 +227,9 @@ class PermissionChecker(object):
         return self.cache.get(permission_name, True)
 
 
-def _getWidgetName(field, widgets, request):
-    if field.__name__ in widgets:
-        factory = widgets[field.__name__]
-    else:
-        factory = getMultiAdapter((field, request), IFieldWidget)
-    if isinstance(factory, six.string_types):
-        return factory
-    if not isinstance(factory, type):
-        factory = factory.__class__
-    return "%s.%s" % (factory.__module__, factory.__name__)
-
-
 def isVisible(name, omitted):
     value = omitted.get(name, False)
-    if isinstance(value, six.string_types):
+    if isinstance(value, str):
         return value == "false"
     return not bool(value)
 
